<?php
	/**************************************************************************\
	* phpGroupWare - QMailLDAP                                                 *
	* http://www.phpgroupware.org                                              *
	* -----------------------------------------------                          *
	*  This program is free software; you can redistribute it and/or modify it *
	*  under the terms of the GNU General Public License as published by the   *
	*  Free Software Foundation; either version 2 of the License, or (at your  *
	*  option) any later version.                                              *
	\**************************************************************************/
	/* $Id: index.php,v 1.1.1.1.4.1 2005/02/28 17:21:16 ceb Exp $ */

	$GLOBALS['phpgw_info']['flags'] = array
	(
		'currentapp' => 'qmailldap',
		'noheader'   => True,
		'nonavbar'   => True
	);
	include('../header.inc.php');

	Header('Location: ' . $GLOBALS['phpgw']->link('/index.php','menuaction=qmailldap.uiqmailldap.listServers'));
	$GLOBALS['phpgw']->common->phpgw_exit();
?>
